package com.huiju.welcome.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.TaCustomerMap;
import com.huiju.welcome.service.ITaCustomerMapService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-06-12
 */
@RestController
@RequestMapping("/")
public class TaCustomerMapController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaCustomerMapController.class);

    @Autowired
    public ITaCustomerMapService iTaCustomerMapService;


    /**
     * 保存对象
     * @param taCustomerMap 实体对象
     * @return
     */
    @RequestMapping(value="/customerMap",method= RequestMethod.POST)
    public ResponseBean save(@RequestBody TaCustomerMap taCustomerMap){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaCustomerMapService.save(taCustomerMap)){
                responseBean.addSuccess(taCustomerMap);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taCustomerMapAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/customerMap/{id}", method= RequestMethod.DELETE)
    public ResponseBean delete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaCustomerMapService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taCustomerMapDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param taCustomerMap 实体对象
     * @return
     */
    @RequestMapping(value="/customerMap/{id}",method= RequestMethod.PUT)
    public ResponseBean update(@RequestBody TaCustomerMap taCustomerMap, @PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaCustomerMapService.updateById(taCustomerMap)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taCustomerMapUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/customerMap/{id}",method= RequestMethod.GET)
    public ResponseBean get(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaCustomerMapService.getById(id));
        }catch (Exception e){
            logger.error("taCustomerMapGetByID -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 分页查询
     */
    @RequestMapping(value="/customerMap",method= RequestMethod.GET)
    public ResponseBean list(
        @RequestParam(defaultValue = "1") int pageNumber,
        @RequestParam(defaultValue = "10") int pageSize
    ){
        ResponseBean responseBean = new ResponseBean();
        try {
            IPage<TaCustomerMap> pg = new Page<>(pageNumber, pageSize);
            QueryWrapper<TaCustomerMap> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaCustomerMap> result = iTaCustomerMapService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("taCustomerMapList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
